#include <Eigen/Dense> //Must be include befor CImg
#include <CImg.h>
#include <iostream>

using namespace cimg_library;
using namespace Eigen;
using namespace std;

vector<float> evaluate(vector<float>& x, vector<float>& y)
{
	int Nx = x.size();
	int Ny = y.size();
	int N = Nx*Ny;
	vector<float> result(N);
	for(int i = 0; i < Nx; ++i)
	{
		for(int j = 0; j < Ny; ++j)
		{
			result[i*Nx+j] = exp(-x[i]*x[i]-y[j]*y[j]);
		}
	}
	return result;
}

vector<Vector3f> applyColorMap( vector<float>& value )
{

	//Create color map
	vector<Vector3f> colorMap;
	colorMap.push_back( Vector3f(255,0,0) );

	vector<Vector3f> color; //pixel color

	int size = value.size();
	for(int i = 0; i < size; ++i)
	{
		color.push_back( colorMap[0] );
	}
	return color;
}

int main()
{

	//Compute data on a grid [0,2]x[0,2]
	float a = -10.0f;
	float b = 10.0f;
	int resolution = 200;
	vector<float> x(resolution),y(resolution);
	for(int i = 0; i < resolution; ++i)
	{
		x[i] = a + i*(b-a)/float(resolution-1);
		y[i] = a + i*(b-a)/float(resolution-1);
	}
	vector<float> value = evaluate(x,y);

	//Apply a color map to value
	vector<Vector3f> color = applyColorMap( value );

	//Create a 500x500x1 image with 3 color, filled with value '0'
	CImg<float> image(resolution,resolution,1,3,0);


	//Assign a color to each pixel from the color map
	for(int i = 0; i < resolution; ++i)
	{
		for(int j = 0; j < resolution; ++j)
		{
			image(i,j,0,0) = color[i*resolution+j][0];
			image(i,j,0,1) = color[i*resolution+j][1];
			image(i,j,0,2) = color[i*resolution+j][2];
		}
	}

	image.save("output.png");

	return 0;
}
